<?php

namespace Testpackageprovider\Test\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Form;
use Testpackageprovider\Test\Http\Requests\TestarticlesAdminRequest;
use Testpackageprovider\Test\Interfaces\TestarticlesRepositoryInterface;
use Testpackageprovider\Test\Models\Testarticles;

/**
 * Admin controller class.
 */
class TestarticlesAdminController extends AdminController
{
    /**
     * Initialize testarticles controller.
     *
     * @param type TestarticlesRepositoryInterface $testarticles
     *
     * @return type
     */
    public function __construct(TestarticlesRepositoryInterface $testarticles)
    {
        parent::__construct();
        $this->repository = $testarticles;
    }

    /**
     * Display a list of testarticles.
     *
     * @return Response
     */
    public function index(TestarticlesAdminRequest $request)
    {
        $testarticles  = $this->repository->setPresenter('\\Testpackageprovider\\Test\\Repositories\\Presenter\\TestarticlesListPresenter')
                                            ->scopeQuery(function($query){
                                                return $query->orderBy('id','DESC');
                                            })->paginate();
        $this   ->theme->prependTitle(trans('test::testarticles.names').' :: ');
        $view   = $this->theme->of('test::admin.testarticles.index')->render();

        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('test::testarticles.name')]);
        $this->responseData = $testarticles['data'];
        $this->responseMeta = $testarticles['meta'];
        $this->responseView = $view;
        $this->responseRedirect = '';
        return $this->respond($request);
    }

    /**
     * Display testarticles.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(TestarticlesAdminRequest $request, Testarticles $testarticles)
    {
        if (!$testarticles->exists) {
            $this->responseCode = 404;
            $this->responseMessage = trans('messages.success.notfound', ['Module' => trans('test::testarticles.name')]);
            $this->responseView = view('test::admin.testarticles.new');
            return $this -> respond($request);
        }

        Form::populate($testarticles);
        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('test::testarticles.name')]);
        $this->responseData = $testarticles;
        $this->responseView = view('test::admin.testarticles.show', compact('testarticles'));
        return $this -> respond($request);
    }

    /**
     * Show the form for creating a new testarticles.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TestarticlesAdminRequest $request)
    {

        $testarticles = $this->repository->newInstance([]);

        Form::populate($testarticles);

        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('test::testarticles.name')]);
        $this->responseData = $testarticles;
        $this->responseView = view('test::admin.testarticles.create', compact('testarticles'));
        return $this -> respond($request);

    }

    /**
     * Create new testarticles.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TestarticlesAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $testarticles = $this->repository->create($attributes);

            $this->responseCode = 201;
            $this->responseMessage = trans('messages.success.created', ['Module' => trans('test::testarticles.name')]);
            $this->responseData = $testarticles;
            $this->responseMeta = '';
            $this->responseRedirect = trans_url('/admin/test/testarticles/'.$testarticles->getRouteKey());
            $this->responseView = view('test::admin.testarticles.create', compact('testarticles'));

            return $this -> respond($request);

        } catch (Exception $e) {
            $this->responseCode = 400;
            $this->responseMessage = $e->getMessage();
            return $this -> respond($request);
        }
    }

    /**
     * Show testarticles for editing.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(TestarticlesAdminRequest $request, Testarticles $testarticles)
    {
        Form::populate($testarticles);
        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('test::testarticles.name')]);
        $this->responseData = $testarticles;
        $this->responseView = view('test::admin.testarticles.edit', compact('testarticles'));

        return $this -> respond($request);
    }

    /**
     * Update the testarticles.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(TestarticlesAdminRequest $request, Testarticles $testarticles)
    {
        try {

            $attributes = $request->all();

            $testarticles->update($attributes);

            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.updated', ['Module' => trans('test::testarticles.name')]);
            $this->responseData = $testarticles;
            $this->responseRedirect = trans_url('/admin/test/testarticles/'.$testarticles->getRouteKey());

            return $this -> respond($request);

        } catch (Exception $e) {

            $this->responseCode = 400;
            $this->responseMessage = $e->getMessage();
            $this->responseRedirect = trans_url('/admin/test/testarticles/'.$testarticles->getRouteKey());

            return $this -> respond($request);
        }
    }

    /**
     * Remove the testarticles.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(TestarticlesAdminRequest $request, Testarticles $testarticles)
    {

        try {

            $t = $testarticles->delete();

            $this->responseCode = 202;
            $this->responseMessage = trans('messages.success.deleted', ['Module' => trans('test::testarticles.name')]);
            $this->responseRedirect = trans_url('/admin/test/testarticles/0');

            return $this -> respond($request);

        } catch (Exception $e) {

            $this->responseCode = 400;
            $this->responseMessage = $e->getMessage();
            $this->responseRedirect = trans_url('/admin/test/testarticles/'.$testarticles->getRouteKey());

            return $this -> respond($request);

        }
    }
}
